@@ -1,8 +1,8 @@
 package BibTeX::Parser;
-
+our $VERSION = '0.4';
+# ABSTRACT: A pure perl BibTeX parser
 use warnings;
 use strict;
-use Text::Balanced qw(extract_bracketed extract_delimited);
 
 use BibTeX::Parser::Entry;
 
@@ -14,12 +14,10 @@ BibTeX::Parser - A pure perl BibTeX parser
 
 =head1 VERSION
 
-Version 0.1
+version 0.4
 
 =cut
 
-our $VERSION = '0.21';
-
 my $re_namechar = qr/[a-zA-Z0-9\!\$\&\*\+\-\.\/\:\;\<\>\?\[\]\^\_\`\|]/o;
 my $re_name     = qr/$re_namechar+/o;
 
@@ -46,8 +44,8 @@ Parses BibTeX files.
 		    my @editors = $entry->editor;
 		    
 		    foreach my $author (@authors) {
-			    print $author->first . " " 
-			    	. $author->von . " " 
+			    print $author->first . " "
+			    	. $author->von . " "
 				. $author->last . ", "
 				. $author->jr;
 		    }
@@ -111,22 +109,30 @@ sub _parse_next {
 
         my $current_entry = new BibTeX::Parser::Entry;
         if (/@($re_name)/cgo) {
-			my $type = uc $1;
+	    my $type = uc $1;
             $current_entry->type( $type );
+            my $start_pos = pos($_) - length($type) - 1;
 
-			# read rest of entry (matches braces
+            # read rest of entry (matches braces)
             my $bracelevel = 0;
             $bracelevel += tr/\{/\{/;    #count braces
             $bracelevel -= tr/\}/\}/;
             while ( $bracelevel != 0 ) {
                 my $position = pos($_);
                 my $line     = $self->{fh}->getline;
+				last unless defined $line;
                 $bracelevel =
                   $bracelevel + ( $line =~ tr/\{/\{/ ) - ( $line =~ tr/\}/\}/ );
                 $_ .= $line;
                 pos($_) = $position;
             }
 
+            # Remember raw bibtex code
+            my $raw = substr($_, $start_pos);
+            $raw =~ s/^\s+//;
+            $raw =~ s/\s+$//;
+            $current_entry->raw_bibtex($raw);
+
             my $pos = pos $_;
             tr/\n/ /;
             pos($_) = $pos;
@@ -230,7 +236,7 @@ sub _parse_string {
         {    # quoted string with embeded escapes
             $value .= $1;
         } else {
-            my $part = ( extract_bracketed( $_, "{}" ) )[0];
+            my $part = _extract_bracketed( $_ );
             $value .= substr $part, 1, length($part) - 2;    # strip quotes
         }
 
@@ -242,17 +248,23 @@ sub _parse_string {
     return $value;
 }
 
-=head1 AUTHOR
+sub _extract_bracketed
+{
+	for($_[0]) # alias to $_
+	{
+		/\G\s+/cg;
+		my $start = pos($_);
+		my $depth = 0;
+		while(1)
+		{
+			/\G\\./cg && next;
+			/\G\{/cg && (++$depth, next);
+			/\G\}/cg && (--$depth > 0 ? next : last);
+			/\G([^\\\{\}]+)/cg && next; 
+			last; # end of string
+		}
+		return substr($_, $start, pos($_)-$start);
+	}
+}
 
-Gerhard Gossen, C<< <gerhard.gossen at googlemail.com> >>
-
-
-=head1 LICENSE
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-
-=cut
-
-1;    # End of BibTeX::Parser
+1;    # End of BibTeX::Parser
\ No newline at end of file
