@@ -1,4 +1,5 @@
 package BibTeX::Parser::Entry;
+our $VERSION = '0.4';
 
 use warnings;
 use strict;
@@ -11,13 +12,10 @@ BibTeX::Entry - Contains a single entry of a BibTeX document.
 
 =head1 VERSION
 
-Version 0.01
+version 0.4
 
 =cut
 
-our $VERSION = '0.2';
-
-
 =head1 SYNOPSIS
 
 This class ist a wrapper for a single BibTeX entry. It is usually created
@@ -53,6 +51,7 @@ sub new {
 	$fields{_type}     = uc($type);
 	$fields{_key}      = $key;
 	$fields{_parse_ok} = $parse_ok;
+        $fields{_raw}      = '';
 	return bless \%fields, $class;
 }
 
@@ -148,7 +147,8 @@ sub _handle_author_editor {
 	my $self = shift;
 	if (@_) {
 		if (@_ == 1) { #single string
-			my @names = split /\s+and\s+/i, $_[0];
+			# my @names = split /\s+and\s+/i, $_[0];
+			my @names = _split_author_field( $_[0] );
 			$self->{"_$type"} = [map {new BibTeX::Parser::Author $_} @names];
 			$self->field($type, join " and ", @{$self->{"_$type"}});
 		} else {
@@ -165,13 +165,53 @@ sub _handle_author_editor {
 		}
 	} else {
 		unless ( defined $self->{"_$type"} ) {
-			my @names = split /\s+and\s+/i, $self->{$type} || "";
+			#my @names = split /\s+and\s+/i, $self->{$type} || "";
+			my @names = _split_author_field( $self->{$type} || "" );
 			$self->{"_$type"} = [map {new BibTeX::Parser::Author $_} @names];
 		}
 		return @{$self->{"_$type"}};
 	}
 }
 
+# _split_author_field($field)
+#
+# Split an author field into different author names.
+# Handles quoted names ({name}).
+sub _split_author_field {
+    my $field = shift;
+
+    return () if !defined $field || $field eq '';
+
+    my @names;
+
+    my $buffer;
+    while (!defined pos $field || pos $field < length $field) {
+	if ( $field =~ /\G ( .* ) ( \{ | \s+ and \s+ )/xcgi ) {
+	    my $match = $1;
+	    if ( $2 =~ /and/i ) {
+		$buffer .= $match;
+		push @names, $buffer;
+		$buffer = "";
+	    } elsif ( $2 =~ /\{/ ) {
+		$buffer .= "{" . $match;
+		if ( $field =~ /\G (.* \})/cgx ) {
+		    $buffer .= $1;
+		} else {
+		    die "Missing closing brace at " . substr( $field, pos $field, 10 );
+		}
+	    } else {
+		$buffer .= $match;
+	    }
+	} else {
+	   print "# $field " . (pos ($field) || 0) . "\n";
+	   $buffer .= substr $field, (pos $field || 0);
+	   last;
+	}
+    }
+    push @names, $buffer if $buffer;
+    return @names;
+}
+
 =head2 author([@authors])
 
 Get or set the authors. Returns an array of L<BibTeX::Author|BibTeX::Author> 
@@ -234,60 +274,19 @@ sub _sanitize_field {
 	return $value;
 }
 
-=head1 AUTHOR
 
-Gerhard Gossen, C<< <gerhard.gossen at googlemail.com> >>
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-bibtex-entry at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=BibTeX-Parser>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc BibTeX::Parser
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=BibTeX-Parser>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/BibTeX-Parser>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/BibTeX-Parser>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/BibTeX-Parser>
-
-=back
-
-
-=head1 ACKNOWLEDGEMENTS
-
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Gerhard Gossen, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head2 raw_bibtex
 
+Return raw BibTeX entry (if available).
 
 =cut
 
-1; # End of BibTeX::Entry
+sub raw_bibtex {
+	my $self = shift;
+	if (@_) {
+		$self->{_raw} = shift;
+	}
+	return $self->{_raw};
+}
+
+1; # End of BibTeX::Entry
\ No newline at end of file
